import psycopg2
from psycopg2.extras import execute_values as p_execute_values
import queries
import os
from dotenv import load_dotenv

load_dotenv()

conn = psycopg2

session = queries.Session(
    queries.uri(
        os.environ.get('PGHOST'),
        os.environ.get('PGPORT'),
        os.environ.get('PGDATABASE'),
        os.environ.get('PGUSER'),
        os.environ.get('PGPASSWORD'),
    ) + (('?application_name=' +
          os.environ.get('PGAPPNAME')) if os.environ.get('PGAPPNAME') else ''))

print("Database connected")

query = session.query


def execute_values(query, values):
    return p_execute_values(session.cursor, query, values)


def insert_value_from_dict(table_name, dictionary, extra_query=''):
    keys = dictionary.keys()

    # TODO: table_name and dictionary.keys and extra_query MUST be constants (sql injection opportunity)
    execute_values(
        'INSERT INTO ' + table_name + ' (' + ','.join(keys) + ') \
                        VALUES %s ' + extra_query, [list(dictionary.values())])


def insert_values_from_dicts(table_name, dictionaries, extra_query=''):
    if not dictionaries:
        return

    # Verify that all dictionaries have identical keys
    if not all(x.keys() == dictionaries[0].keys() for x in dictionaries):
        raise ValueError("Dictionaries have different keys")

    keys = dictionaries[0].keys()

    # TODO: table_name and dictionary.keys and extra_query MUST be constants (sql injection opportunity)
    execute_values(
        'INSERT INTO ' + table_name + ' (' + ','.join(keys) + ') \
                        VALUES %s ' + extra_query,
        (list(x.values()) for x in dictionaries))



import setuptools
import os

if os.environ.get('CI_COMMIT_TAG'):
    version = os.environ['CI_COMMIT_TAG']
else:
    version = os.environ['CI_JOB_ID']

setuptools.setup(
    name="griffin-db",
    version=version,
    author="Adrian Campos",
    author_email="adrian@g4tv.com",
    description="A small wrapper for psycopg2 and queries with commonly used functions",
    packages=setuptools.find_packages(),
    install_requires=[
        "queries~=2.1.0",
        "python-dotenv",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        # "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    zip_safe=False,
)
